==> OpenPatricianDisplay-0.4.0-sources.jar: ch/sahits/game/graphic/javafx/display/MarketSceneEventHandler.java <==
package ch.sahits.game.graphic.javafx.display;

import ch.sahits.game.event.EViewChangeEvent;
import ch.sahits.game.graphic.display.dialog.util.EDialogType;
import ch.sahits.game.graphic.display.gameplay.internal.EScene;
import ch.sahits.game.graphic.display.model.ViewChangeCityPlayerProxyJFX;
import ch.sahits.game.graphic.display.notice.ENoticeItem;
import com.google.common.base.Preconditions;
import javafx.beans.property.ObjectProperty;
import javafx.beans.property.SimpleObjectProperty;
import org.springframework.stereotype.Component;

/**
 * @author Andi Hotz, (c) Sahits GmbH, 2013
 *         Created on Dec 13, 2013
 */
@Component
public class MarketSceneEventHandler implements ISceneEventHandler {
    private ObjectProperty<EScene> currentScene = new SimpleObjectProperty<>(this, "currentScene", EScene.PORT);
    private IDialogContoller dialogContoller; // this instance exists not at startup
    @Override
    public ObjectProperty<EScene> currentSceneProperty() {
        return currentScene;
    }

    @Override
    public void setDialogContoller(IDialogContoller dialogContoller) {
        this.dialogContoller = dialogContoller;
    }

    @Override
    public void handleEvent(Object eventNotice) {
        Preconditions.checkNotNull(dialogContoller, "Dialog controller must be initialized first");
            if (eventNotice == EViewChangeEvent.CLOSE_DIALOG) {
                dialogContoller.closeDialog();
            }
            if (eventNotice instanceof ViewChangeCityPlayerProxyJFX) {
                ViewChangeCityPlayerProxyJFX cityProxy = (ViewChangeCityPlayerProxyJFX) eventNotice;
                // trade city ship
                if (cityProxy.getViewChangeEvent() == EViewChangeEvent.NOTICE_MARKET_BOOTH) {
                    // Dialog City ship
                    dialogContoller.setNewDialog(EDialogType.MB_STOCK_PRICES);
                }
                 // Scene change market place
                if (cityProxy.getViewChangeEvent() == EViewChangeEvent.MAIN_VIEW_PORT) {
                    currentScene.set(EScene.PORT);
                    dialogContoller.changeScene();
                }
                if (cityProxy.getViewChangeEvent() == EViewChangeEvent.MAIN_VIEW_CITY_HALL) {
                    currentScene.set(EScene.CITY_HALL);
                    dialogContoller.changeScene();
                }

            }
            if (eventNotice instanceof ENoticeItem) {
                EDialogType dialogType;
                switch ((ENoticeItem)eventNotice) {
                    case MB_CONSUMPTION_PRODUCTION:
                        dialogType = EDialogType.MB_CONSUMPTION_PRODUCTION;
                        break;
                    case MB_STOCK_PRICES:
                        dialogType = EDialogType.MB_STOCK_PRICES;
                        break;
                    default:
                        throw new RuntimeException("Not yet implemented eventNotice: "+eventNotice);
                }
                dialogContoller.replaceDialog(dialogType);
            }
    }
}

==> OpenPatricianDisplay-0.6.0-sources.jar: ch/sahits/game/graphic/javafx/display/MarketSceneEventHandler.java <==
package ch.sahits.game.graphic.javafx.display;

import ch.sahits.game.event.EViewChangeEvent;
import ch.sahits.game.graphic.display.gameplay.internal.EScene;
import ch.sahits.game.graphic.display.model.ViewChangeCityPlayerProxyJFX;
import ch.sahits.game.javafx.model.EDialogType;
import ch.sahits.game.openpatrician.annotation.ClassCategory;
import ch.sahits.game.openpatrician.annotation.DependentInitialisation;
import ch.sahits.game.openpatrician.annotation.EClassCategory;
import ch.sahits.game.openpatrician.annotation.ObjectPropertyType;
import ch.sahits.game.openpatrician.util.StartNewGameBean;
import com.google.common.base.Preconditions;
import javafx.beans.property.ObjectProperty;
import javafx.beans.property.SimpleObjectProperty;
import org.springframework.context.annotation.Lazy;
import org.springframework.stereotype.Component;

/**
 * @author Andi Hotz, (c) Sahits GmbH, 2013
 *         Created on Dec 13, 2013
 */
@Component
@Lazy
@DependentInitialisation(StartNewGameBean.class)
@ClassCategory(EClassCategory.HANDLER)
public class MarketSceneEventHandler implements ISceneEventHandler {
    @ObjectPropertyType(EScene.class)
    private ObjectProperty<EScene> currentScene = new SimpleObjectProperty<>(this, "currentScene", EScene.PORT);
    private IDialogContoller dialogContoller; // this instance exists not at startup
    @Override
    public ObjectProperty<EScene> currentSceneProperty() {
        return currentScene;
    }

    @Override
    public void setDialogContoller(IDialogContoller dialogContoller) {
        this.dialogContoller = dialogContoller;
    }

    @Override
    public void handleEvent(Object eventNotice) {
        Preconditions.checkNotNull(dialogContoller, "Dialog controller must be initialized first");
            if (eventNotice instanceof ViewChangeCityPlayerProxyJFX) {
                ViewChangeCityPlayerProxyJFX cityProxy = (ViewChangeCityPlayerProxyJFX) eventNotice;
                // trade city ship
                if (cityProxy.getViewChangeEvent() == EViewChangeEvent.NOTICE_MARKET_BOOTH) {
                    // Dialog City ship
                    dialogContoller.setNewDialog(EDialogType.MB_STOCK_PRICES);
                }
                 // Scene change market place
                if (cityProxy.getViewChangeEvent() == EViewChangeEvent.MAIN_VIEW_PORT) {
                    currentScene.set(EScene.PORT);
                    dialogContoller.changeScene();
                }
                if (cityProxy.getViewChangeEvent() == EViewChangeEvent.MAIN_VIEW_CITY_HALL) {
                    currentScene.set(EScene.CITY_HALL);
                    dialogContoller.changeScene();
                }
                if (cityProxy.getViewChangeEvent() == EViewChangeEvent.MAIN_VIEW_CHURCH) {
                    currentScene.set(EScene.CHURCH);
                    dialogContoller.changeScene();
                }
            }
        if (eventNotice instanceof EDialogType) {
            dialogContoller.replaceDialog((EDialogType) eventNotice);
        }
    }
}
